@@ -11,7 +11,7 @@ def rotate(pixel_coor:[int,int],degrees:int,rotate_coor:[int,int])->[int,int]:
   rx , ry = rotate_coor
   dx , dy = abs(px-rx), abs(py-ry)
   
-  a = degrees-math.atan2(dy,dx)*180/math.pi
+  a = degrees-2*math.atan2(dy,dx)*180/math.pi
   r = math.sqrt(dx**2+dy**2)
 
   px , py = rx , ry
